@@ -87,16 +87,8 @@ def buildWidget(Project, *args, **kwargs):
     js = ""
     js += "require.config({" + eol
     js += "  paths: {" + eol
-    js += "    'react': 'https://unpkg.com/react@16.8.6/umd/react.development'," + eol
-    js += "    'react-dom': 'https://unpkg.com/react-dom@16.8.6/umd/react-dom.development'," + eol
-    js += "    'material-ui': 'https://unpkg.com/@material-ui/core@latest/umd/material-ui.development'," + eol
-    js += "    'plotlycomponent': 'https://unpkg.com/react-plotly.js@2.3/dist/create-plotly-component'," + eol
-    js += "    'plotly': 'https://cdn.plot.ly/plotly-1.52.0.min'," + eol
-    js += "    'math': 'https://cdnjs.cloudflare.com/ajax/libs/mathjs/6.6.1/math.min'," + eol
-    js += "    'axios': 'https://unpkg.com/axios/dist/axios.min'," + eol
-    js += "    'localforage' : 'https://www.unpkg.com/localforage@1.7.3/dist/localforage.min'," + eol
-    js += "    'number-format': 'https://unpkg.com/react-number-format@4.3.1/dist/react-number-format'," + eol
-    js += "    'prop-types': 'https://unpkg.com/prop-types@15.6/prop-types.min'" + eol
+    for k,v in self.libraries.items():
+        js += "    '" + k + "': '" + v +"',\n"
     js += "  }" + eol
     js += "});" + eol
     js += "require.undef('" + component + "')" + eol
@@ -106,6 +98,7 @@ def buildWidget(Project, *args, **kwargs):
     js += "    'react', " + eol
     js += "    'react-dom'," + eol
     js += "    'material-ui'," + eol
+    js += "    'materiallab-ui'," + eol
     js += "    'number-format'," + eol
     js += "    'axios'," + eol
     js += "    'localforage'," + eol
@@ -119,6 +112,7 @@ def buildWidget(Project, *args, **kwargs):
     js += "    React, " + eol
     js += "    ReactDOM," + eol
     js += "    Material," + eol
+    js += "    MaterialLab," + eol
     js += "    Format," + eol
     js += "    Axios," + eol
     js += "    LocalForage," + eol
@@ -205,7 +199,9 @@ def buildWidget(Project, *args, **kwargs):
     js += "          for (let [key, value] of Object.entries(state)) {" + eol
     js += "            backbone.model.set(key, value);" + eol
     js += "          }" + eol
-    js += "          backbone.model.save_changes();" + eol
+    js += "          try {;" + eol
+    js += "            backbone.model.save_changes();" + eol
+    js += "          } catch (error) { console.log(error); }" + eol
     js += "          orig.apply(this, [state, callback]);" + eol
     js += "        }" + eol
     for i in serializers:   
@@ -256,6 +252,8 @@ def buildWidget(Project, *args, **kwargs):
     js += "      " + component + "Model" + eol
     js += "    };" + eol
     js += "});" + eol
+    if kwargs.get("verbose", False):
+        print(js)
     #out = widgets.Output()
     #display(out)
     #with out:
@@ -267,7 +265,19 @@ def buildWidget(Project, *args, **kwargs):
                 return;
         #widgets.Widget._handle_msg(s,c,b)
 
-    def do_init(s, v, f, **k):
+    def do_init(s, v, f, **k):    
+        default_styles = "<link rel='stylesheet' href='https://fonts.googleapis.com/icon?family=Material+Icons'/>"
+        default_styles += "<style>.p-Widget * {font-size: unset;}</style>"
+        default_styles += "<style>div.output_subarea {padding: 0px;}</style>"
+        
+        display(
+            widgets.HTML(
+                kwargs.get("styles", default_styles),
+                layout=widgets.Layout(display="none")
+            )
+        )
+        display(Javascript(js))
+
         widgets.DOMWidget.__init__(s,**k)
         for i,j in f.items():
             setattr(s,'_handlers_'+ i, widgets.widget.CallbackDispatcher())
@@ -280,6 +290,7 @@ def buildWidget(Project, *args, **kwargs):
         
         for i,j in v.items():
             setattr(s,i,k.get(i,j))
+
         
     def do__setattr(s,n,v,d):
         if (hasattr(s, '__validate')):
@@ -314,14 +325,7 @@ def buildWidget(Project, *args, **kwargs):
     attrs['_handle_uidl_msg'] =  lambda s,c,b, : do_handle_msg(s, default, functions, c, b)
     attrs['__setattr__'] =  lambda s,n,v, d=default : do__setattr (s,n,v,d) 
 
-    
-    default_styles = "<link rel='stylesheet' href='https://fonts.googleapis.com/icon?family=Material+Icons'/>"
-    display(HTML("<style>.p-Widget * {font-size: unset;}</style>"))
-    display(HTML(kwargs.get("styles", default_styles)))
-    if kwargs.get("verbose", False):
-        print(js)
-    display(Javascript(js))
-                    
+                        
     return type(component + 'Widget', (widgets.DOMWidget,), attrs)
 
 def parseJSX(document, *args, **kwargs):
