@@ -7,6 +7,11 @@ class MaterialContent(TeleportContent):
     return "Material." + elementType
 
 
+class MaterialLabContent(TeleportContent):
+
+  def buildElementType(self):   
+    elementType = self.elementType
+    return "MaterialLab." + elementType
 
 class MaterialBuilder():
   def AppBar(*args, **kwargs):
@@ -36,7 +41,7 @@ class MaterialBuilder():
     Typography.addContent(TypographyText)
 
     if kwargs.get("state", None) is not None:
-      states = {0:"unfold_more", 1:"unfold_less"}
+      states = {0:"arrow_forward_ios", 1:"arrow_back_ios"}
       for k,v in states.items():
         IconButton = TeleportElement(MaterialContent(elementType="IconButton"))
         IconButton.content.attrs["edge"] = "start"
@@ -54,7 +59,8 @@ class MaterialBuilder():
           IconButton.content.events["click"].append({
             "type": "stateChange",
             "modifies": styles[0],
-            "newState": styles[1][k]
+            "newState": styles[1][k],
+            "callbacks": kwargs.get("callbacks", [])
           })
         
         Icon = TeleportElement(MaterialContent(elementType="Icon"))
@@ -80,7 +86,7 @@ class MaterialBuilder():
       if kwargs.get("onClickMenu", None) is not None:
         IconButton.content.events["click"] = kwargs.get("onClickMenu", [])
       Icon = TeleportElement(MaterialContent(elementType="Icon"))
-      IconText = TeleportStatic(content="unfold_more")
+      IconText = TeleportStatic(content="arrow_forward_ios")
       Icon.addContent(IconText)   
       IconButton.addContent(Icon)
       ToolBar.addContent(IconButton)
@@ -158,20 +164,20 @@ class MaterialBuilder():
     >>> ExpansionPanel(state="DrawerIsVisible", position="static", "variant":"dense" )
 
     """  
-    ExpansionPanel = TeleportElement(MaterialContent(elementType="ExpansionPanel"))
+    ExpansionPanel = TeleportElement(MaterialContent(elementType="Accordion"))
     if kwargs.get("disabled", False) is True:
         ExpansionPanel.content.attrs["disabled"] = True
     if kwargs.get("expanded", None) is not None:
         ExpansionPanel.content.attrs["expanded"] = kwargs.get("expanded", False)
     if kwargs.get("defaultExpanded", None) is not None:
         ExpansionPanel.content.attrs["defaultExpanded"] = kwargs.get("defaultExpanded", True)
-    ExpansionPanelSummary = TeleportElement(MaterialContent(elementType="ExpansionPanelSummary"))
+    ExpansionPanelSummary = TeleportElement(MaterialContent(elementType="AccordionSummary"))
     ExpansionPanelSummary.content.attrs["expandIcon"] = "expand_more"
     ExpansionPanelSummary.content.attrs["aria-controls"] = kwargs.get("aria-controls", "panel1a-content")
     ExpansionPanelSummary.content.attrs["id"] = kwargs.get("id", kwargs.get("title", ""))
-    ExpansionPanelSummary.content.style = {'backgroundColor' : '#dbeaf0' }
+    ExpansionPanelSummary.content.style = {'backgroundColor' : '#dbeaf0', 'display' : 'flex', 'padding' : '20px' }
 
-    ExpansionPanelDetails = TeleportElement(MaterialContent(elementType="ExpansionPanelDetails"))
+    ExpansionPanelDetails = TeleportElement(MaterialContent(elementType="AccordionDetails"))
     ExpansionPanelDetails.content.style = {"padding" : "0px"}
     if kwargs.get("content", None) is not None:
         for content in kwargs.get("content", []):
@@ -270,7 +276,7 @@ class MaterialBuilder():
           'root': { 'color': 'rgba(0, 0, 0, 0.54)' },
         },
         'MuiGrid' : {
-          'item' : { 'display' : 'flex', 'flex-direction' : 'column', 'padding': '4px' }
+          'item' : { 'display' : 'flex', 'flexDirection' : 'column', 'padding': '4px' }
         },
         'MuiDrawer' : {
           'paper' : {
@@ -288,6 +294,13 @@ class MaterialBuilder():
             'backgroundColor':secondary_bg
           },
         },
+        #'MuiButtonBase' : {
+        #    'root' : {
+        #        'text-transform' : 'none',
+        #        'padding' : '6px 16px',
+        #        'border-radius' : '4px',
+        #    },
+        #},
         'MuiButton' : {
             'root' : {
                 'text-transform' : 'none',
@@ -317,6 +330,14 @@ class MaterialBuilder():
               "width" : "none"
           }
         },
+        'MuiAccordionSummary' : {
+          'content' : {
+            'padding': '20px',
+            '&$expanded': {
+              'padding': '20px',
+            },
+          },    
+        },
         'MuiExpansionPanelSummary':{
           'expandIcon' : {
               'font-family': 'Material Icons'
@@ -391,6 +412,9 @@ class MaterialBuilder():
           'colorSecondary':{
               'color' : secondary_button,
               'background-color' : secondary_button_bg,
+          },
+          'label' : {
+              'font-family': 'Material Icons',
           }
         },
         'MuiOutlinedInput' : {
@@ -410,8 +434,22 @@ class MaterialBuilder():
             '@media (min-width:600px)':{
                 'min-width' : '90px',
                 'padding' : '2px'                
-             }
+            }
           }
+        },
+        'MuiAccordionSummary' : {
+          'content' : {
+            "margin": "0px",
+            "&$expanded": {
+              "margin": "0px",
+            }
+          },          
+          'root' : {
+            "min-height": "20px",
+            "&$expanded": {
+              "min-height" : "20px"
+            }
+          },
         }
       },  
     }
@@ -419,7 +457,7 @@ class MaterialBuilder():
   def ThemeProvider(Component, theme):  
     Component.addPropVariable("createMuiTheme", {
         "type":"func", 
-        "defaultValue": "() => {return Material.createMuiTheme(" + json.dumps(theme) + ");}"
+        "defaultValue": "() => {return Material.createTheme(" + json.dumps(theme) + ");}"
     })
     ThemeProvider = TeleportElement(MaterialContent(elementType="ThemeProvider"))
     ThemeProvider.content.attrs["theme"] = {
@@ -513,7 +551,7 @@ class MaterialComponents():
     IComponent.addPropVariable("onDefaultValue", {"type":"func", "defaultValue": "(l,v)=>{return l.find((e)=>{return e.key==v})}"})
     
     bvalues = { True : "primary",  False : "secondary"}    
-    ExpansionPanel = TeleportElement(MaterialContent(elementType="ExpansionPanel"))
+    ExpansionPanel = TeleportElement(MaterialContent(elementType="Accordion"))
     ExpansionPanel.content.attrs["expanded"] = {
       "type": "dynamic",
       "content": {
@@ -522,7 +560,7 @@ class MaterialComponents():
       }    
     }
     ExpansionPanel.content.attrs["defaultExpanded"] = True
-    ExpansionPanelSummary = TeleportElement(MaterialContent(elementType="ExpansionPanelSummary"))
+    ExpansionPanelSummary = TeleportElement(MaterialContent(elementType="AccordionSummary"))
     ExpansionPanelSummary.content.attrs["expandIcon"] = "expand_more"
     ExpansionPanelSummary.content.attrs["aria-controls"] = kwargs.get("aria-controls", "panel1a-content")
 
@@ -560,7 +598,7 @@ class MaterialComponents():
     Typography.addContent(TeleportStatic(content="  "))
     ExpansionPanelSummary.addContent(Typography)        
                                            
-    ExpansionPanelDetails = TeleportElement(MaterialContent(elementType="ExpansionPanelDetails"))
+    ExpansionPanelDetails = TeleportElement(MaterialContent(elementType="AccordionDetails"))
 
     Grid = TeleportElement(MaterialContent(elementType="Grid"))
     Grid.content.attrs["container"] = True
@@ -637,7 +675,7 @@ class MaterialComponents():
   def ButtonList(tp, *args, **kwargs ):
    
     bvalues = { True : "primary",  False : "secondary"}    
-    ExpansionPanel = TeleportElement(MaterialContent(elementType="ExpansionPanel"))
+    ExpansionPanel = TeleportElement(MaterialContent(elementType="Accordion"))
     ExpansionPanel.content.attrs["expanded"] = {
       "type": "dynamic",
       "content": {
@@ -646,7 +684,7 @@ class MaterialComponents():
       }    
     }
     ExpansionPanel.content.attrs["defaultExpanded"] = True
-    ExpansionPanelSummary = TeleportElement(MaterialContent(elementType="ExpansionPanelSummary"))
+    ExpansionPanelSummary = TeleportElement(MaterialContent(elementType="AccordionSummary"))
     ExpansionPanelSummary.content.attrs["expandIcon"] = "expand_more"
     ExpansionPanelSummary.content.attrs["aria-controls"] = kwargs.get("aria-controls", "panel1a-content")                                         
 
@@ -657,7 +695,7 @@ class MaterialComponents():
     Typography.addContent(TeleportStatic(content="  "))
     ExpansionPanelSummary.addContent(Typography)        
                                            
-    ExpansionPanelDetails = TeleportElement(MaterialContent(elementType="ExpansionPanelDetails"))
+    ExpansionPanelDetails = TeleportElement(MaterialContent(elementType="AccordionDetails"))
 
     Grid = TeleportElement(MaterialContent(elementType="Grid"))
     Grid.content.attrs["container"] = True
@@ -1043,4 +1081,4 @@ class MaterialComponents():
     Paper.addContent(Grid)
     
     tp.addComponent("ColorSliders", CComponent);    
-    return "ColorSliders";
\ No newline at end of file
+    return "ColorSliders";
